*WMS* stands for [Web Map Service](https://en.wikipedia.org/wiki/Web_Map_Service).
A WMS may offer one or more map layers.

**WMS URL**: The URL of a WMS, for example
`https://geodienste.hamburg.de/HH_WMS_Gewaesserunterhaltung`.

**WMS Layer**: Once you have entered a valid WMS URL, you can select one of
its offered layers here.
